###############
Purchase Module
###############

The *Purchase Module* provides everything that is required to create and
manage purchases made by the company.
It adds the idea of a purchase to Tryton, and allows it to be tracked as it
moves through various states from draft to done.
It makes it easy to create supplier shipments for the purchase, and includes
the ability to automatically create related supplier invoices.

.. toctree::
   :maxdepth: 2

   usage/index
   design
